# -*- coding: UTF-8 -*-
# Copyright 2017 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

"""Extends :mod:`lino.modlib.users` for :ref:`avanti`.

.. autosummary::
   :toctree:

    models
    ui
    fixtures.demo
    fixtures.demo2

"""

from lino.modlib.users import Plugin


# class Plugin(Plugin):
    
#     extends_models = ['User']

